summaryrefslogtreecommitdiffstats
path: root/konsolekalendar/konsolekalendarexports.h
diff options
context:
space:
mode:
Diffstat (limited to 'konsolekalendar/konsolekalendarexports.h')
-rw-r--r--konsolekalendar/konsolekalendarexports.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/konsolekalendar/konsolekalendarexports.h b/konsolekalendar/konsolekalendarexports.h
index dc2f44ec..8db27c97 100644
--- a/konsolekalendar/konsolekalendarexports.h
+++ b/konsolekalendar/konsolekalendarexports.h
@@ -28,7 +28,7 @@
#ifndef _KONSOLEKALENDAREXPORTS_H_
#define _KONSOLEKALENDAREXPORTS_H_
-#include <qtextstream.h>
+#include <tqtextstream.h>
#include "konsolekalendarvariables.h"
@@ -60,28 +60,28 @@ namespace KCal
/**
* Export the Event in Text Mode.
* @param ts pointer to the output QTextStream.
* @param event pointer to the Event to export.
* @param date is the QDate to be exported for.
*/
- bool exportAsTxt( QTextStream *ts, Event *event, QDate date );
+ bool exportAsTxt( TQTextStream *ts, Event *event, TQDate date );
/**
* Export the Event in Short Text Mode.
* @param ts pointer to the output QTextStream.
* @param event pointer to the Event to export.
* @param date is the QDate to be exported for.
* @param sameday flags that this Event is on the same date as the
* previously exported Event.
*/
- bool exportAsTxtShort( QTextStream *ts, Event *event, QDate date,
+ bool exportAsTxtShort( TQTextStream *ts, Event *event, TQDate date,
bool sameday );
/**
* Export the Event in Comma-Separated Values (CSV) Mode.
* @param ts pointer to the output QTextStream.
* @param event pointer to the Event to export.
* @param date is the QDate to be exported for.
*/
- bool exportAsCSV( QTextStream *ts, Event *event, QDate date );
+ bool exportAsCSV( TQTextStream *ts, Event *event, TQDate date );
private:
KonsoleKalendarVariables *m_variables;
@@ -91,9 +91,9 @@ namespace KCal
* 1. Replaces double quotes by a pair of consecutive double quotes
* 2. Surrounds field with double quotes
* @param field is the field value to be processed.
* @param dquote is a QString containing the double quote character.
*/
- QString processField( QString field, QString dquote );
+ TQString processField( TQString field, TQString dquote );
};
@@ -60,28 +60,28 @@ namespace KCal
/**
* Export the Event in Text Mode.
- * @param ts pointer to the output QTextStream.
+ * @param ts pointer to the output TQTextStream.
* @param event pointer to the Event to export.
@@ -60,28 +60,28 @@ namespace KCal
* @param event pointer to the Event to export.
- * @param date is the QDate to be exported for.
+ * @param date is the TQDate to be exported for.
*/
@@ -60,28 +60,28 @@ namespace KCal
/**
* Export the Event in Short Text Mode.
- * @param ts pointer to the output QTextStream.
+ * @param ts pointer to the output TQTextStream.
* @param event pointer to the Event to export.
@@ -60,28 +60,28 @@ namespace KCal
* @param event pointer to the Event to export.
- * @param date is the QDate to be exported for.
+ * @param date is the TQDate to be exported for.
* @param sameday flags that this Event is on the same date as the
* previously exported Event.
@@ -60,28 +60,28 @@ namespace KCal
/**
* Export the Event in Comma-Separated Values (CSV) Mode.
- * @param ts pointer to the output QTextStream.
+ * @param ts pointer to the output TQTextStream.
* @param event pointer to the Event to export.
@@ -60,28 +60,28 @@ namespace KCal
* @param event pointer to the Event to export.
- * @param date is the QDate to be exported for.
+ * @param date is the TQDate to be exported for.
*/
@@ -91,9 +91,9 @@ namespace KCal
* 2. Surrounds field with double quotes
* @param field is the field value to be processed.
- * @param dquote is a QString containing the double quote character.
+ * @param dquote is a TQString containing the double quote character.
*/